likbgev: Log likelihood function for the bimodal GEV distribution.
Description
Uses the density function to evaluate the likelihood. This is useful for the
'bgev.mle' function.
Usage
likbgev(y, theta = c(1, 1, 0.3, 2))
Value
a unidimensional vector containing the computed log likelihood for y.
Arguments
y
a unidimensional vector containing the points to compute the log likelihood
theta
bimodal GEV parameters as an ordered pair theta = (mu,sigma,xi,delta)
Author
tools:::Rd_package_author("bgev")
References
Otiniano, Cira EG, et al. (2023). A bimodal model for extremes data. Environmental and Ecological Statistics, 1-28. http://dx.doi.org/10.1007/s10651-023-00566-7